@@ -1,13 +1,19 @@
 package Tree::Suffix;
 
 use strict;
-use vars qw($VERSION);
+use vars qw($VERSION @ISA);
 
-$VERSION = '0.13';
-
-require XSLoader;
-XSLoader::load('Tree::Suffix', $VERSION);
+$VERSION = '0.14';
 
+eval {
+  require XSLoader;
+  XSLoader::load('Tree::Suffix', $VERSION);
+  1;
+} or do {
+  require DynaLoader;
+  push @ISA, 'DynaLoader';
+  bootstrap Tree::Suffix $VERSION;
+};
 
 1;
 
